
do
    --协议名称是bsvp， 在Packet Details窗格显示为
    local p_bsvp = Proto("bsvp","BSVP Log Protocol")

    --头协议各个字段含义，需要放到此处注册
    local s_log_level = {[2]="CRIT", [3]="ERROR", [4]="WARNING", [5]="NOTICE", [6]="INFO", [7]="DEBUG", [8]="VERBOSE"}
    local f_pid = ProtoField.uint32("bsvp.pid", "pid", base.DEC_HEX)
    local f_tid = ProtoField.uint32("bsvp.tid", "tid", base.DEC_HEX)
    local f_level = ProtoField.uint8("bsvp.level", "level", base.DEC, s_log_level)
    local f_tag = ProtoField.stringz("bsvp.tag", "tag", base.ASCII)
    local f_tid_name = ProtoField.stringz("bsvp.tid_name", "tid_name", base.ASCII)
    local f_file = ProtoField.stringz("bsvp.file", "file", base.ASCII)
    local f_file_line = ProtoField.uint32("bsvp.line", "line", base.DEC)
    local f_func = ProtoField.stringz("bsvp.func", "func", base.ASCII)
    local f_msg = ProtoField.string("bsvp.msg", "msg", base.ASCII)
    p_bsvp.fields = {f_pid, f_tid, f_level, f_tag, f_tid_name, f_file, f_file_line, f_func, f_msg}

    --获取数据
    local data = Dissector.get("data")
    local offset = 0;

    --数据分析函数
    local function bsap_dissector(buf,pkg,root)
        local buf_len = buf:len()

        -- 协议信息展示a
        pkg.cols.protocol = "bsvp"

        --添加头
        local header = root:add(p_bsvp, buf)

        local pid =  buf(0, 4):le_uint()
        header:add(f_pid, pid)

        local tid =  buf(4, 4):le_uint()
        header:add(f_tid, tid)

        local level = buf(8, 1)
        header:add(f_level, level)

        offset = 9
        local _len = buf(offset, -1):stringz():len()
        local tag = buf(offset, _len)
        header:add(f_tag, tag)

        offset = offset + _len + 1
        _len = buf(offset, -1):stringz():len()
        local tid_name = buf(offset, _len)
        header:add(f_tid_name, tid_name)

        offset = offset + _len + 1
        _len = buf(offset, -1):stringz():len()
        header:add(f_file, buf(offset, _len))

        offset = offset + _len + 1
        _len = buf(offset, -1):stringz():len()
        local line =  tonumber(buf(offset, _len):string())
        header:add(f_file_line, line)

        offset = offset + _len + 1
        _len = buf(offset, -1):stringz():len()
        local func = buf(offset, _len)
        header:add(f_func, func)

        offset = offset + _len + 1
        _len = buf(offset, -1):stringz():len()
        local msg = buf(offset, _len-1)
        header:add(f_msg, msg)

        pkg.cols.info = string.format("%s %d --- [%s] %s %s(): %s", s_log_level[level:int()], tid, tid_name:string(), tag:string(), func:string(), msg:string())
        offset = buf_len
        return true
    end

    --解析函数，注意，该function前面不能添加local
    function p_bsvp.dissector(buf,pkg,root)
        --如果解析符合本协议
        if bsap_dissector(buf,pkg,root) then
            --有效的协议，未处理完的字段调用其他协议继续解析
            local buf_len = buf:len()
            if offset + 1 < buf_len then
                data:call(buf(offset, buf_len-offset), pkg, root)
            end

        --如果解析不符合本协议，返回给主程序继续遍历其他协议
        else
            data:call(buf,pkg,root)
        end
    end

    local serial_encap_table = DissectorTable.get("wtap_encap")
    --截取所有的bsap协议
    --USER0~USER15是45到60，可以自定义解析，参见源码wtap.h
    serial_encap_table:add(45, p_bsvp)

end